@@ -9,7 +9,7 @@
  *  http://www.rtems.com/license/LICENSE.
  *
  *
- *  $Id: bsp.h,v 1.9 2005/05/26 05:28:00 ralf Exp $
+ *  $Id$
 */
 #ifndef _BSP_H
 #define _BSP_H
@@ -25,6 +25,8 @@ extern "C" {
 #include <rtems/console.h>
 #include <rtems/clockdrv.h>
 
+#define BSP_FEATURE_IRQ_EXTENSION
+
 /*
  *  Define the interrupt mechanism for Time Test 27
  *
@@ -35,11 +37,6 @@ struct rtems_bsdnet_ifconfig;
 int cs8900_driver_attach (struct rtems_bsdnet_ifconfig *config,
                           int                          attaching);
 
-#define CONFIGURE_NUMBER_OF_TERMIOS_PORTS 2
-#define CONFIGURE_INTERRUPT_STACK_MEMORY  (16 * 1024)
-
-extern rtems_configuration_table BSP_Configuration;
-
 /*
  * Network driver configuration
  */
