@@ -8,7 +8,7 @@
 #include <bsp.h>
 
 void
-Timer_initialize(void)
+benchmark_timer_initialize(void)
 {
     int preScaleDivisor = 58;
     int div = MCF5282_TIMER_DTMR_CLK_DIV1;
@@ -22,22 +22,12 @@ Timer_initialize(void)
  * Return timer value in microsecond units
  */
 int
-Read_timer(void)
+benchmark_timer_read(void)
 {
     return MCF5282_TIMER3_DTCN;
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-rtems_status_code
-Empty_function(void)
-{
-    return RTEMS_SUCCESSFUL;
-}
-
 void
-Set_find_average_overhead(rtems_boolean find_flag)
+benchmark_timer_disable_subtracting_average_overhead(bool find_flag)
 {
 }
