@@ -1,25 +1,25 @@
-/* 
+/*
  *  This file implements a benchmark timer using the count/compare
  *  CP0 registers.
  *
  *  Copyright (c) 2005 by Cogent Computer Systems
  *  Written by Jay Monkman <jtm@lopingdog.com>
- *	
+ *
  *  The license and distribution terms for this file may be
  *  found in found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: timer.c,v 1.3 2007/03/12 11:17:51 joel Exp $
+ *  $Id$
  */
 
 #include <assert.h>
 
 #include <bsp.h>
 
-rtems_boolean Timer_driver_Find_average_overhead;
+bool benchmark_timer_find_average_overhead;
 uint32_t tstart;
 
-void Timer_initialize()
+void benchmark_timer_initialize(void)
 {
     asm volatile ("mfc0 %0, $9\n" : "=r" (tstart));
     /* tick time in picooseconds */
@@ -30,7 +30,7 @@ void Timer_initialize()
 #define LEAST_VALID       1  /* Don't trust a value lower than this */
                              /* tx39 simulator can count instructions. :) */
 
-int Read_timer()
+int benchmark_timer_read(void)
 {
   uint32_t  total;
   uint32_t  cnt;
@@ -41,7 +41,7 @@ int Read_timer()
   total = (total * 1000) / 396; /* convert to nanoseconds */
 
 
-  if ( Timer_driver_Find_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == true )
     return total;          /* in one microsecond units */
 
   if ( total < LEAST_VALID )
@@ -50,14 +50,9 @@ int Read_timer()
   return total - AVG_OVERHEAD;
 }
 
-rtems_status_code Empty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void Set_find_average_overhead(
-  rtems_boolean find_flag
+void benchmark_timer_disable_subtracting_average_overhead(
+  bool find_flag
 )
 {
-  Timer_driver_Find_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
