@@ -10,7 +10,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: bsp.h,v 1.16 2006/03/17 10:34:12 ralf Exp $
+ *  $Id$
  */
 
 #ifndef _BSP_H
@@ -28,28 +28,8 @@ extern "C" {
 #include <rtems/clockdrv.h>
 #include <libcpu/tx3904.h>
 
-/* Constants */
-
-/* miscellaneous stuff assumed to exist */
-
-extern rtems_configuration_table BSP_Configuration;
-
-/*
- *  Device Driver Table Entries
- */
-
-/*
- * NOTE: Use the standard Console driver entry
- */
-
-/*
- * NOTE: Use the standard Clock driver entry
- */
-
 /* functions */
 
-void bsp_cleanup( void );
-
 rtems_isr_entry set_vector(
   rtems_isr_entry, rtems_vector_number, int );
 
