@@ -5,14 +5,14 @@
  *  with the name given in name.  The node is set to point to the node at
  *  to_loc.
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2009.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: imfs_symlink.c,v 1.9 2004/04/17 08:34:41 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -20,6 +20,8 @@
 #endif
 
 #include <errno.h>
+#include <string.h>
+#include <stdlib.h>
 #include "imfs.h"
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
@@ -38,15 +40,26 @@ int IMFS_symlink(
   /*
    * Remove any separators at the end of the string.
    */
+  IMFS_get_token( node_name, strlen( node_name ), new_name, &i );
 
-  IMFS_get_token( node_name, new_name, &i );
-
-  info.sym_link.name = link_name;
+  /*
+   * Duplicate link name
+   */
+  info.sym_link.name = strdup(link_name);
+  if (info.sym_link.name == NULL) {
+    rtems_set_errno_and_return_minus_one(ENOMEM);
+  }
 
   /*
    *  Create a new link node.
+   *
+   *  NOTE: Coverity CID 22 notes this as a resource leak.
+   *        While technically not a leak, it indicated that IMFS_create_node
+   *        was ONLY passed a NULL when we created the root node.  We
+   *        added a new IMFS_create_root_node() so this path no longer
+   *        existed.  The result was simpler code which should not have
+   *        this path. 
    */
-
   new_node = IMFS_create_node(
     parent_loc,
     IMFS_SYM_LINK,
@@ -55,8 +68,10 @@ int IMFS_symlink(
     &info
   );
 
-  if ( !new_node )
-    rtems_set_errno_and_return_minus_one( ENOMEM );
+  if (new_node == NULL) {
+    free(info.sym_link.name);
+    rtems_set_errno_and_return_minus_one(ENOMEM);
+  }
 
   return 0;
 }
