@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -31,9 +27,13 @@
  * SUCH DAMAGE.
  *
  *	@(#)tcp_input.c	8.12 (Berkeley) 5/24/95
- *	$Id: tcp_input.c,v 1.9 2007/05/10 05:12:54 ralf Exp $
+ *	$Id$
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "opt_tcpdebug.h"
 
 #ifndef TUBA_INCLUDE
@@ -47,7 +47,7 @@
 #include <sys/protosw.h>
 #include <sys/socket.h>
 #include <sys/socketvar.h>
-#include <sys/errno.h>
+#include <errno.h>
 #include <sys/syslog.h>
 
 #include <machine/cpu.h>	/* before tcp_seq.h, for tcp_random18() */
@@ -147,10 +147,7 @@ static void	 tcp_xmit_timer(struct tcpcb *, int);
 #ifndef TUBA_INCLUDE
 
 static int
-tcp_reass(tp, ti, m)
-	register struct tcpcb *tp;
-	register struct tcpiphdr *ti;
-	struct mbuf *m;
+tcp_reass(struct tcpcb *tp, struct tcpiphdr *ti, struct mbuf *m)
 {
 	register struct tcpiphdr *q;
 	struct socket *so = tp->t_inpcb->inp_socket;
@@ -274,9 +271,7 @@ present:
  * protocol specification dated September, 1981 very closely.
  */
 void
-tcp_input(m, iphlen)
-	register struct mbuf *m;
-	int iphlen;
+tcp_input(struct mbuf *m, int iphlen)
 {
 	register struct tcpiphdr *ti;
 	register struct inpcb *inp;
@@ -1736,12 +1731,8 @@ drop:
 }
 
 static void
-tcp_dooptions(tp, cp, cnt, ti, to)
-	struct tcpcb *tp;
-	u_char *cp;
-	int cnt;
-	struct tcpiphdr *ti;
-	struct tcpopt *to;
+tcp_dooptions(struct tcpcb *tp, u_char *cp, int cnt, struct tcpiphdr *ti,
+	struct tcpopt *to)
 {
 	u_short mss = 0;
 	int opt, optlen;
@@ -1853,10 +1844,7 @@ tcp_dooptions(tp, cp, cnt, ti, to)
  * sequencing purposes.
  */
 static void
-tcp_pulloutofband(so, ti, m)
-	struct socket *so;
-	struct tcpiphdr *ti;
-	register struct mbuf *m;
+tcp_pulloutofband(struct socket *so, struct tcpiphdr *ti, struct mbuf *m)
 {
 	int cnt = ti->ti_urp - 1;
 
@@ -1884,11 +1872,9 @@ tcp_pulloutofband(so, ti, m)
  * and update averages and current timeout.
  */
 static void
-tcp_xmit_timer(tp, rtt)
-	register struct tcpcb *tp;
-	short rtt;
+tcp_xmit_timer(struct tcpcb *tp, int rtt)
 {
-	register int delta;
+	int delta;
 
 	tcpstat.tcps_rttupdated++;
 	tp->t_rttupdated++;
@@ -1986,9 +1972,7 @@ tcp_xmit_timer(tp, rtt)
  * MSS of our peer.
  */
 void
-tcp_mss(tp, offer)
-	struct tcpcb *tp;
-	int offer;
+tcp_mss(struct tcpcb *tp, int offer)
 {
 	register struct rtentry *rt;
 	struct ifnet *ifp;
@@ -2151,8 +2135,7 @@ tcp_mss(tp, offer)
  * Determine the MSS option to send on an outgoing SYN.
  */
 int
-tcp_mssopt(tp)
-	struct tcpcb *tp;
+tcp_mssopt(struct tcpcb *tp)
 {
 	struct rtentry *rt;
 
