@@ -1,5 +1,12 @@
 /*
- *  $Id: clockgetcpuclockid.c,v 1.4 2007/03/26 22:56:12 joel Exp $
+ *  COPYRIGHT (c) 1989-2007.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -27,5 +34,5 @@ int clock_getcpuclockid(
   clockid_t *clock_id
 )
 {
-  return POSIX_NOT_IMPLEMENTED();
+  rtems_set_errno_and_return_minus_one( ENOSYS );
 }
