@@ -33,7 +33,7 @@
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#define RCSID	"$Id: chap.c,v 1.8 2007/03/27 15:47:35 ralf Exp $"
+#define RCSID	"$Id$"
 
 /*
  * TODO:
@@ -59,16 +59,16 @@ static const char rcsid[] = RCSID;
  */
 static option_t chap_option_list[] = {
     { "chap-restart", o_int, &chap[0].timeouttime,
-      "Set timeout for CHAP" },
+      "Set timeout for CHAP", 0, NULL, 0, 0 },
     { "chap-max-challenge", o_int, &chap[0].max_transmits,
-      "Set max #xmits for challenge" },
+      "Set max #xmits for challenge", 0, NULL, 0, 0 },
     { "chap-interval", o_int, &chap[0].chal_interval,
-      "Set interval for rechallenge" },
+      "Set interval for rechallenge", 0, NULL, 0, 0 },
 #ifdef MSLANMAN
     { "ms-lanman", o_bool, &ms_lanman,
-      "Use LanMan passwd when using MS-CHAP", 1 },
+      "Use LanMan passwd when using MS-CHAP", 1, NULL, 0, 0 },
 #endif
-    { NULL }
+    { NULL, 0, NULL, NULL, 0,  NULL, 0, 0 }
 };
 
 /*
@@ -120,8 +120,8 @@ static void ChapGenChallenge(chap_state *);
  * ChapInit - Initialize a CHAP unit.
  */
 static void
-ChapInit(unit)
-    int unit;
+ChapInit(
+    int unit)
 {
     chap_state *cstate = &chap[unit];
 
@@ -140,10 +140,10 @@ ChapInit(unit)
  *
  */
 void
-ChapAuthWithPeer(unit, our_name, digest)
-    int unit;
-    char *our_name;
-    int digest;
+ChapAuthWithPeer(
+    int unit,
+    char *our_name,
+    int digest)
 {
     chap_state *cstate = &chap[unit];
 
@@ -159,7 +159,7 @@ ChapAuthWithPeer(unit, our_name, digest)
 
     /*
      * We get here as a result of LCP coming up.
-     * So even if CHAP was open before, we will 
+     * So even if CHAP was open before, we will
      * have to re-authenticate ourselves.
      */
     cstate->clientstate = CHAPCS_LISTEN;
@@ -170,13 +170,13 @@ ChapAuthWithPeer(unit, our_name, digest)
  * ChapAuthPeer - Authenticate our peer (start server).
  */
 void
-ChapAuthPeer(unit, our_name, digest)
-    int unit;
-    char *our_name;
-    int digest;
+ChapAuthPeer(
+    int unit,
+    char *our_name,
+    int digest)
 {
     chap_state *cstate = &chap[unit];
-  
+
     cstate->chal_name = our_name;
     cstate->chal_type = digest;
 
@@ -197,11 +197,11 @@ ChapAuthPeer(unit, our_name, digest)
  * ChapChallengeTimeout - Timeout expired on sending challenge.
  */
 static void
-ChapChallengeTimeout(arg)
-    void *arg;
+ChapChallengeTimeout(
+    void *arg)
 {
     chap_state *cstate = (chap_state *) arg;
-  
+
     /* if we aren't sending challenges, don't worry.  then again we */
     /* probably shouldn't be here either */
     if (cstate->serverstate != CHAPSS_INITIAL_CHAL &&
@@ -224,8 +224,8 @@ ChapChallengeTimeout(arg)
  * ChapResponseTimeout - Timeout expired on sending response.
  */
 static void
-ChapResponseTimeout(arg)
-    void *arg;
+ChapResponseTimeout(
+    void *arg)
 {
     chap_state *cstate = (chap_state *) arg;
 
@@ -241,8 +241,8 @@ ChapResponseTimeout(arg)
  * ChapRechallenge - Time to challenge the peer again.
  */
 static void
-ChapRechallenge(arg)
-    void *arg;
+ChapRechallenge(
+    void *arg)
 {
     chap_state *cstate = (chap_state *) arg;
 
@@ -262,11 +262,11 @@ ChapRechallenge(arg)
  * Start up if we have pending requests.
  */
 static void
-ChapLowerUp(unit)
-    int unit;
+ChapLowerUp(
+    int unit)
 {
     chap_state *cstate = &chap[unit];
-  
+
     if (cstate->clientstate == CHAPCS_INITIAL)
 	cstate->clientstate = CHAPCS_CLOSED;
     else if (cstate->clientstate == CHAPCS_PENDING)
@@ -288,11 +288,11 @@ ChapLowerUp(unit)
  * Cancel all timeouts.
  */
 static void
-ChapLowerDown(unit)
-    int unit;
+ChapLowerDown(
+    int unit)
 {
     chap_state *cstate = &chap[unit];
-  
+
     /* Timeout(s) pending?  Cancel if so. */
     if (cstate->serverstate == CHAPSS_INITIAL_CHAL ||
 	cstate->serverstate == CHAPSS_RECHALLENGE)
@@ -312,8 +312,8 @@ ChapLowerDown(unit)
  * ChapProtocolReject - Peer doesn't grok CHAP.
  */
 static void
-ChapProtocolReject(unit)
-    int unit;
+ChapProtocolReject(
+    int unit)
 {
     chap_state *cstate = &chap[unit];
 
@@ -331,16 +331,16 @@ ChapProtocolReject(unit)
  * ChapInput - Input CHAP packet.
  */
 static void
-ChapInput(unit, inpacket, packet_len)
-    int unit;
-    u_char *inpacket;
-    int packet_len;
+ChapInput(
+    int unit,
+    u_char *inpacket,
+    int packet_len)
 {
     chap_state *cstate = &chap[unit];
     u_char *inp;
     u_char code, id;
     int len;
-  
+
     /*
      * Parse header (code, id and length).
      * If packet too short, drop it.
@@ -362,7 +362,7 @@ ChapInput(unit, inpacket, packet_len)
 	return;
     }
     len -= CHAP_HEADERLEN;
-  
+
     /*
      * Action depends on code (as in fact it usually does :-).
      */
@@ -370,11 +370,11 @@ ChapInput(unit, inpacket, packet_len)
     case CHAP_CHALLENGE:
 	ChapReceiveChallenge(cstate, inp, id, len);
 	break;
-    
+
     case CHAP_RESPONSE:
 	ChapReceiveResponse(cstate, inp, id, len);
 	break;
-    
+
     case CHAP_FAILURE:
 	ChapReceiveFailure(cstate, inp, id, len);
 	break;
@@ -394,11 +394,11 @@ ChapInput(unit, inpacket, packet_len)
  * ChapReceiveChallenge - Receive Challenge and send Response.
  */
 static void
-ChapReceiveChallenge(cstate, inp, id, len)
-    chap_state *cstate;
-    u_char *inp;
-    int id;
-    int len;
+ChapReceiveChallenge(
+    chap_state *cstate,
+    u_char *inp,
+    int id,
+    int len)
 {
     int rchallenge_len;
     u_char *rchallenge;
@@ -407,7 +407,7 @@ ChapReceiveChallenge(cstate, inp, id, len)
     char rhostname[256];
     MD5_CTX mdContext;
     u_char hash[MD5_SIGNATURE_SIZE];
- 
+
     if (cstate->clientstate == CHAPCS_CLOSED ||
 	cstate->clientstate == CHAPCS_PENDING) {
 	CHAPDEBUG(("ChapReceiveChallenge: in state %d", cstate->clientstate));
@@ -455,7 +455,7 @@ ChapReceiveChallenge(cstate, inp, id, len)
     cstate->resp_transmits = 0;
 
     /*  generate MD based on negotiated type */
-    switch (cstate->resp_type) { 
+    switch (cstate->resp_type) {
 
     case CHAP_DIGEST_MD5:
 	MD5Init(&mdContext);
@@ -487,11 +487,11 @@ ChapReceiveChallenge(cstate, inp, id, len)
  * ChapReceiveResponse - Receive and process response.
  */
 static void
-ChapReceiveResponse(cstate, inp, id, len)
-    chap_state *cstate;
-    u_char *inp;
-    int id;
-    int len;
+ChapReceiveResponse(
+    chap_state *cstate,
+    u_char *inp,
+    int id,
+    int len)
 {
     u_char *remmd, remmd_len;
     int secret_len, old_state;
@@ -556,7 +556,7 @@ ChapReceiveResponse(cstate, inp, id, len)
     } else {
 
 	/*  generate MD based on negotiated type */
-	switch (cstate->chal_type) { 
+	switch (cstate->chal_type) {
 
 	case CHAP_DIGEST_MD5:		/* only MD5 is defined for now */
 	    if (remmd_len != MD5_SIGNATURE_SIZE)
@@ -565,7 +565,7 @@ ChapReceiveResponse(cstate, inp, id, len)
 	    MD5Update(&mdContext, &cstate->chal_id, 1);
 	    MD5Update(&mdContext, secret, secret_len);
 	    MD5Update(&mdContext, cstate->challenge, cstate->chal_len);
-	    MD5Final(hash, &mdContext); 
+	    MD5Final(hash, &mdContext);
 
 	    /* compare local and remote MDs and send the appropriate status */
 	    if (memcmp (hash, remmd, MD5_SIGNATURE_SIZE) == 0)
@@ -601,11 +601,11 @@ ChapReceiveResponse(cstate, inp, id, len)
  * ChapReceiveSuccess - Receive Success
  */
 static void
-ChapReceiveSuccess(cstate, inp, id, len)
-    chap_state *cstate;
-    u_char *inp;
-    u_char id;
-    int len;
+ChapReceiveSuccess(
+    chap_state *cstate,
+    u_char *inp,
+    u_char id,
+    int len)
 {
 
     if (cstate->clientstate == CHAPCS_OPEN)
@@ -636,11 +636,11 @@ ChapReceiveSuccess(cstate, inp, id, len)
  * ChapReceiveFailure - Receive failure.
  */
 static void
-ChapReceiveFailure(cstate, inp, id, len)
-    chap_state *cstate;
-    u_char *inp;
-    u_char id;
-    int len;
+ChapReceiveFailure(
+    chap_state *cstate,
+    u_char *inp,
+    u_char id,
+    int len)
 {
     if (cstate->clientstate != CHAPCS_RESPONSE) {
 	/* don't know what this is */
@@ -665,8 +665,8 @@ ChapReceiveFailure(cstate, inp, id, len)
  * ChapSendChallenge - Send an Authenticate challenge.
  */
 static void
-ChapSendChallenge(cstate)
-    chap_state *cstate;
+ChapSendChallenge(
+    chap_state *cstate)
 {
     u_char *outp;
     int chal_len, name_len;
@@ -690,7 +690,7 @@ ChapSendChallenge(cstate)
     BCOPY(cstate->chal_name, outp, name_len);	/* append hostname */
 
     output(cstate->unit, outpacket_buf, outlen + PPP_HDRLEN);
-  
+
     TIMEOUT(ChapChallengeTimeout, cstate, cstate->timeouttime);
     ++cstate->chal_transmits;
 }
@@ -700,9 +700,9 @@ ChapSendChallenge(cstate)
  * ChapSendStatus - Send a status response (ack or nak).
  */
 static void
-ChapSendStatus(cstate, code)
-    chap_state *cstate;
-    int code;
+ChapSendStatus(
+    chap_state *cstate,
+    int code)
 {
     u_char *outp;
     int outlen, msglen;
@@ -718,7 +718,7 @@ ChapSendStatus(cstate, code)
     outp = outpacket_buf;
 
     MAKEHEADER(outp, PPP_CHAP);	/* paste in a header */
-  
+
     PUTCHAR(code, outp);
     PUTCHAR(cstate->chal_id, outp);
     PUTSHORT(outlen, outp);
@@ -734,15 +734,15 @@ ChapSendStatus(cstate, code)
  */
 
 static void
-ChapGenChallenge(cstate)
-    chap_state *cstate;
+ChapGenChallenge(
+    chap_state *cstate)
 {
     int chal_len;
     u_char *ptr = cstate->challenge;
     int i;
 
-    /* pick a random challenge length between MIN_CHALLENGE_LENGTH and 
-       MAX_CHALLENGE_LENGTH */  
+    /* pick a random challenge length between MIN_CHALLENGE_LENGTH and
+       MAX_CHALLENGE_LENGTH */
     chal_len =  (unsigned) ((drand48() *
 			     (MAX_CHALLENGE_LENGTH - MIN_CHALLENGE_LENGTH)) +
 			    MIN_CHALLENGE_LENGTH);
@@ -761,8 +761,8 @@ ChapGenChallenge(cstate)
  */
 /* ARGSUSED */
 static void
-ChapSendResponse(cstate)
-    chap_state *cstate;
+ChapSendResponse(
+    chap_state *cstate)
 {
     u_char *outp;
     int outlen, md_len, name_len;
@@ -800,11 +800,11 @@ static char *ChapCodenames[] = {
 };
 
 static int
-ChapPrintPkt(p, plen, printer, arg)
-    u_char *p;
-    int plen;
-    void (*printer)(void *, char *, ...);
-    void *arg;
+ChapPrintPkt(
+    u_char *p,
+    int plen,
+    void (*printer)(void *, char *, ...),
+    void *arg)
 {
     int code, id, len;
     int clen, nlen;
