@@ -13,7 +13,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: types.h,v 1.10 2006/11/17 05:57:36 ralf Exp $
+ *  $Id$
  */
 
 #ifndef _RTEMS_SCORE_TYPES_H
@@ -21,7 +21,8 @@
 
 #ifndef ASM
 
-#include <rtems/stdint.h>
+#include <stdbool.h>
+#include <stdint.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -32,15 +33,15 @@ extern "C" {
  */
 
 typedef uint16_t     Priority_Bit_map_control;
-
-typedef uint32_t boolean;     /* Boolean value   */
-
-typedef float          single_precision;     /* single precision float */
-typedef double         double_precision;     /* double precision float */
-
 typedef void h8300_isr;
 typedef void ( *h8300_isr_entry )( void );
 
+#ifdef RTEMS_DEPRECATED_TYPES
+typedef bool	boolean;     		/* Boolean value   */
+typedef float	single_precision;	/* single precision float */
+typedef double	double_precision;	/* double precision float */
+#endif
+
 #ifdef __cplusplus
 }
 #endif
