@@ -13,20 +13,21 @@
  *
  *  + Anywhere there is an XXX, it should be replaced
  *    with information about the CPU family being ported to.
- *  
+ *
  *  + At the end of each comment section, there is a heading which
  *    says "Port Specific Information:".  When porting to RTEMS,
  *    add CPU family specific information in this section
  */
 
-/*  COPYRIGHT (c) 1989-2006.
+/*
+ *  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: cpu.h,v 1.19 2007/04/17 05:57:14 ralf Exp $
+ *  $Id$
  */
 
 #ifndef _RTEMS_SCORE_CPU_H
@@ -118,6 +119,19 @@ extern "C" {
  */
 #define CPU_HAS_SOFTWARE_INTERRUPT_STACK FALSE
 
+/**
+ *  Does the CPU follow the simple vectored interrupt model?
+ *
+ *  If TRUE, then RTEMS allocates the vector table it internally manages.
+ *  If FALSE, then the BSP is assumed to allocate and manage the vector
+ *  table
+ *
+ *  Port Specific Information:
+ *
+ *  XXX document implementation including references if appropriate
+ */
+#define CPU_SIMPLE_VECTORED_INTERRUPTS TRUE
+
 /**
  *  Does this CPU have hardware support for a dedicated interrupt stack?
  *
@@ -154,7 +168,7 @@ extern "C" {
 
 /**
  *  Does the RTEMS invoke the user's ISR with the vector number and
- *  a pointer to the saved interrupt frame (1) or just the vector 
+ *  a pointer to the saved interrupt frame (1) or just the vector
  *  number (0)?
  *
  *  Port Specific Information:
@@ -181,7 +195,7 @@ extern "C" {
  *  an i387 and wish to leave floating point support out of RTEMS.
  */
 
-/** 
+/**
  *  @def CPU_SOFTWARE_FP
  *
  *  Does the CPU have no hardware floating point and GCC provides a
@@ -189,7 +203,7 @@ extern "C" {
  *  switched?
  *
  *  This feature conditional is used to indicate whether or not there
- *  is software implemented floating point that must be context 
+ *  is software implemented floating point that must be context
  *  switched.  The determination of whether or not this applies
  *  is very tool specific and the state saved/restored is also
  *  compiler specific.
@@ -452,16 +466,33 @@ extern "C" {
  *  to another.
  */
 typedef struct {
-    /** This field is a hint that a port will have a number of integer 
+    /** This field is a hint that a port will have a number of integer
      *  registers that need to be saved at a context switch.
      */
     uint32_t   some_integer_register;
-    /** This field is a hint that a port will have a number of system 
+    /** This field is a hint that a port will have a number of system
      *  registers that need to be saved at a context switch.
      */
     uint32_t   some_system_register;
+
+    /** This field is a hint that a port will have a register that
+     *  is the stack pointer.
+     */
+    uint32_t   stack_pointer;
 } Context_Control;
 
+/**
+ *  @ingroup CPUContext Management
+ *
+ *  This macro returns the stack pointer associated with @a _context.
+ *
+ *  @param[in] _context is the thread context area to access
+ *
+ *  @return This method returns the stack pointer.
+ */
+#define _CPU_Context_Get_SP( _context ) \
+  (_context)->stack_pointer
+
 /**
  *  @ingroup CPUContext Management
  *  This defines the complete set of floating point registers that must
@@ -479,85 +510,13 @@ typedef struct {
  *  in @ref Context_Control.
  */
 typedef struct {
-    /** This field is a hint that a port will have a number of integer 
+    /** This field is a hint that a port will have a number of integer
      *  registers that need to be saved when an interrupt occurs or
      *  when a context switch occurs at the end of an ISR.
      */
     uint32_t   special_interrupt_register;
 } CPU_Interrupt_frame;
 
-
-/**
- *  The following table contains the information required to configure
- *  the XXX processor specific parameters.
- *
- *  Port Specific Information:
- *
- *  XXX document implementation including references if appropriate
- */
-
-typedef struct {
-  /** This element points to the BSP's pretasking hook. */
-  void       (*pretasking_hook)( void );
-  /** This element points to the BSP's predriver hook. */
-  void       (*predriver_hook)( void );
-  /** This element points to the BSP's postdriver hook. */
-  void       (*postdriver_hook)( void );
-  /** This element points to the BSP's optional idle task which may override
-   *  the default one provided with RTEMS.
-   */
-  void       (*idle_task)( void );
-  /** If this element is TRUE, then RTEMS will zero the Executive Workspace.
-   *  When this element is FALSE, it is assumed that the BSP or invoking
-   *  environment has ensured that memory was cleared before RTEMS was 
-   *  invoked.
-   */
-  boolean      do_zero_of_workspace;
-  /** This field specifies the size of the IDLE task's stack.  If less than or
-   *  equal to the minimum stack size, then the IDLE task will have the minimum
-   *  stack size.
-   */
-  uint32_t     idle_task_stack_size;
-  /** This field specifies the size of the interrupt stack.  If less than or
-   *  equal to the minimum stack size, then the interrupt stack will be of
-   *  minimum stack size.
-   */
-  uint32_t     interrupt_stack_size;
-  /** The MPCI Receive server is assumed to have a stack of at least 
-   *  minimum stack size.  This field specifies the amount of extra
-   *  stack this task will be given in bytes.
-   */
-  uint32_t     extra_mpci_receive_server_stack;
-  /** The BSP may want to provide it's own stack allocation routines.
-   *  In this case, the BSP will provide this stack allocation hook.
-   */
-  void *     (*stack_allocate_hook)( uint32_t   );
-  /** The BSP may want to provide it's own stack free routines.
-   *  In this case, the BSP will provide this stack free hook.
-   */
-  void       (*stack_free_hook)( void *);
-  /* end of fields required on all CPUs */
-}   rtems_cpu_table;
-
-/*
- *  Macros to access required entires in the CPU Table are in 
- *  the file rtems/system.h.
- *
- *  Port Specific Information:
- *
- *  XXX document implementation including references if appropriate
- */
-
-/*
- *  Macros to access NO_CPU specific additions to the CPU Table
- *
- *  Port Specific Information:
- *
- *  XXX document implementation including references if appropriate
- */
-
-/* There are no CPU specific additions to the CPU Table for this port. */
-
 /**
  *  This variable is optional.  It is used on CPUs on which it is difficult
  *  to generate an "uninitialized" FP context.  It is filled in by
@@ -591,34 +550,18 @@ SCORE_EXTERN Context_Control_fp  _CPU_Null_fp_context;
 
 /**
  *  @ingroup CPUInterrupt
- *  This variable points to the lowest physical address of the interrupt 
+ *  This variable points to the lowest physical address of the interrupt
  *  stack.
  */
 SCORE_EXTERN void               *_CPU_Interrupt_stack_low;
 
 /**
  *  @ingroup CPUInterrupt
- *  This variable points to the lowest physical address of the interrupt 
+ *  This variable points to the lowest physical address of the interrupt
  *  stack.
  */
 SCORE_EXTERN void               *_CPU_Interrupt_stack_high;
 
-/**
- *  @ingroup CPUInterrupt
- *  With some compilation systems, it is difficult if not impossible to
- *  call a high-level language routine from assembly language.  This
- *  is especially true of commercial Ada compilers and name mangling
- *  C++ ones.  This variable can be optionally defined by the CPU porter
- *  and contains the address of the routine @ref _Thread_Dispatch.  This
- *  can make it easier to invoke that routine at the end of the interrupt
- *  sequence (if a dispatch is necessary).
- *
- *  Port Specific Information:
- *
- *  XXX document implementation including references if appropriate
- */
-SCORE_EXTERN void           (*_CPU_Thread_dispatch_pointer)();
-
 /*
  *  Nothing prevents the porter from declaring more CPU specific variables.
  *
@@ -708,7 +651,7 @@ SCORE_EXTERN void           (*_CPU_Thread_dispatch_pointer)();
  *
  *  @note  This does not have to be a power of 2 although it should be
  *         a multiple of 2 greater than or equal to 2.  The requirement
- *         to be a multiple of 2 is because the heap uses the least 
+ *         to be a multiple of 2 is because the heap uses the least
  *         significant field of the front and back flags to indicate
  *         that a block is in use or free.  So you do not want any odd
  *         length blocks really putting length data in that bit.
@@ -983,7 +926,7 @@ uint32_t   _CPU_ISR_Get_level( void );
 /**
  *  @defgroup CPUBitfield Processor Dependent Bitfield Manipulation
  *
- *  This set of routines are used to implement fast searches for 
+ *  This set of routines are used to implement fast searches for
  *  the most important ready task.
  */
 
@@ -1008,7 +951,7 @@ uint32_t   _CPU_ISR_Get_level( void );
 /**
  *  @ingroup CPUBitfield
  *  This routine sets @a _output to the bit number of the first bit
- *  set in @a _value.  @a _value is of CPU dependent type 
+ *  set in @a _value.  @a _value is of CPU dependent type
  *  @a Priority_Bit_map_control.  This type may be either 16 or 32 bits
  *  wide although only the 16 least significant bits will be used.
  *
@@ -1051,14 +994,14 @@ uint32_t   _CPU_ISR_Get_level( void );
         if _value > 0x00ff
           _value >>=8
           _number = 8;
-  
+
         if _value > 0x0000f
           _value >=8
           _number += 4
-  
+
         _number += bit_set_table[ _value ]
 @endverbatim
-  
+
  *    where bit_set_table[ 16 ] has values which indicate the first
  *      bit set
  *
@@ -1122,21 +1065,15 @@ uint32_t   _CPU_ISR_Get_level( void );
 /**
  *  This routine performs CPU dependent initialization.
  *
- *  @param[in] cpu_table is the CPU Dependent Configuration Table
- *  @param[in] thread_dispatch is the address of @ref _Thread_Dispatch
- *
  *  Port Specific Information:
  *
  *  XXX document implementation including references if appropriate
  */
-void _CPU_Initialize(
-  rtems_cpu_table  *cpu_table,
-  void      (*thread_dispatch)
-);
+void _CPU_Initialize(void);
 
 /**
  *  @ingroup CPUInterrupt
- *  This routine installs a "raw" interrupt handler directly into the 
+ *  This routine installs a "raw" interrupt handler directly into the
  *  processor's vector table.
  *
  *  @param[in] vector is the vector number
@@ -1194,7 +1131,7 @@ void _CPU_Install_interrupt_stack( void );
  *
  *  XXX document implementation including references if appropriate
  */
-void _CPU_Thread_Idle_body( void );
+void *_CPU_Thread_Idle_body( uintptr_t ignored );
 
 /**
  *  @ingroup CPUContext
@@ -1297,15 +1234,15 @@ static inline uint32_t CPU_swap_u32(
   uint32_t value
 )
 {
-  uint32_t   byte1, byte2, byte3, byte4, swapped;
- 
+  uint32_t byte1, byte2, byte3, byte4, swapped;
+
   byte4 = (value >> 24) & 0xff;
   byte3 = (value >> 16) & 0xff;
   byte2 = (value >> 8)  & 0xff;
   byte1 =  value        & 0xff;
- 
+
   swapped = (byte1 << 24) | (byte2 << 16) | (byte3 << 8) | byte4;
-  return( swapped );
+  return swapped;
 }
 
 /**
