@@ -14,7 +14,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: coresemflush.c,v 1.6 2005/01/27 05:57:04 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -27,9 +27,6 @@
 #include <rtems/score/states.h>
 #include <rtems/score/thread.h>
 #include <rtems/score/threadq.h>
-#if defined(RTEMS_MULTIPROCESSING)
-#include <rtems/score/mpci.h>
-#endif
 
 /*PAGE
  *
