@@ -2,14 +2,14 @@
  *  Time of Day (TOD) Handler - get uptime
  */
 
-/*  COPYRIGHT (c) 1989-2007.
+/*  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: coretodgetuptime.c,v 1.2 2007/04/05 21:17:27 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -18,8 +18,9 @@
 
 #include <rtems/system.h>
 #include <rtems/score/isr.h>
-#include <rtems/score/timespec.h>
+#include <rtems/score/timestamp.h>
 #include <rtems/score/tod.h>
+#include <rtems/score/watchdog.h>
 
 /*
  *  _TOD_Get_uptime
@@ -27,28 +28,31 @@
  *  This routine is used to obtain the system uptime
  *
  *  Input parameters:
- *    time  - pointer to the time and date structure
+ *    time  - pointer to the timestamp structure
  *
  *  Output parameters: NONE
  */
 
 void _TOD_Get_uptime(
-  struct timespec *uptime
+  Timestamp_Control *uptime
 )
 {
-  ISR_Level level;
-  struct timespec offset;
+  ISR_Level         level;
+  Timestamp_Control offset;
+  Timestamp_Control up;
+  long              nanoseconds;
 
-  /* assume uptime checked by caller */
-
-  offset.tv_sec = 0;
-  offset.tv_nsec = 0;
+  /* assume time checked for NULL by caller */
 
+  /* _TOD_Uptime is in native timestamp format */
+  nanoseconds = 0;
   _ISR_Disable( level );
-    *uptime = _TOD_Uptime;
+    up = _TOD_Uptime;
     if ( _Watchdog_Nanoseconds_since_tick_handler )
-      offset.tv_nsec = (*_Watchdog_Nanoseconds_since_tick_handler)();
+      nanoseconds = (*_Watchdog_Nanoseconds_since_tick_handler)();
   _ISR_Enable( level );
 
-  _Timespec_Add_to( uptime, &offset );
+  _Timestamp_Set( &offset, 0, nanoseconds );
+  _Timestamp_Add_to( &up, &offset );
+  *uptime = up;
 }
