@@ -5,9 +5,9 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: empty.c,v 1.1 2007/07/17 22:32:12 joel Exp $
+ *  $Id$
  */
 
 /* put here hoping it won't get inlined */
-void dummy_function_empty_body_to_force_call() {}
+void dummy_function_empty_body_to_force_call(void) {}
 
