@@ -15,7 +15,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: trestart.c,v 1.10 2004/04/16 09:19:06 ralf Exp $
+ *  $Id$
  */
 
 #include "system.h"
@@ -30,11 +30,17 @@ void Task_restart_extension(
 
   if ( task_number( restarted_task->Object.id ) > 0 ) {
     name = Task_name[ task_number( restarted_task->Object.id ) ];
+/*
+ * FIXME: There should be a public function to
+ * convert numeric rtems_names into char arrays
+ * c.f. rtems_name_to_characters() in rtems/rtems/support.inl
+ * but it's private.
+ */
     sprintf( line, "TASK_RESTART - %c%c%c%c - restarted\n",
-      (name >> 24) & 0xff,
-      (name >> 16) & 0xff,
-      (name >> 8) & 0xff,
-      name & 0xff
+      (char)((name >> 24) & 0xff),
+      (char)((name >> 16) & 0xff),
+      (char)((name >> 8) & 0xff),
+      (char)(name & 0xff)
     );
     buffered_io_add_string( line );
   }
